"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing
import yandex.cloud.logging.v1.log_entry_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _TriggerType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _TriggerTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_TriggerType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    TRIGGER_TYPE_UNSPECIFIED: _TriggerType.ValueType  # 0
    TIMER: _TriggerType.ValueType  # 2
    """The trigger is activated on a timer."""
    MESSAGE_QUEUE: _TriggerType.ValueType  # 3
    """The trigger is activated by messages from a message queue.

    Only Message Queue is currently supported.
    """
    IOT_MESSAGE: _TriggerType.ValueType  # 4
    """The trigger is activated by messages from IoT Core."""
    IOT_BROKER_MESSAGE: _TriggerType.ValueType  # 12
    OBJECT_STORAGE: _TriggerType.ValueType  # 5
    CONTAINER_REGISTRY: _TriggerType.ValueType  # 6
    CLOUD_LOGS: _TriggerType.ValueType  # 7
    """The trigger is activated by cloud log group events"""
    LOGGING: _TriggerType.ValueType  # 8
    """The trigger is activated by logging group events"""
    BILLING_BUDGET: _TriggerType.ValueType  # 9
    """The trigger is activated by billing events"""
    YDS: _TriggerType.ValueType  # 10
    """The trigger is activated by YDS events"""
    MAIL: _TriggerType.ValueType  # 11
    """The trigger is activated by email"""

class TriggerType(_TriggerType, metaclass=_TriggerTypeEnumTypeWrapper): ...

TRIGGER_TYPE_UNSPECIFIED: TriggerType.ValueType  # 0
TIMER: TriggerType.ValueType  # 2
"""The trigger is activated on a timer."""
MESSAGE_QUEUE: TriggerType.ValueType  # 3
"""The trigger is activated by messages from a message queue.

Only Message Queue is currently supported.
"""
IOT_MESSAGE: TriggerType.ValueType  # 4
"""The trigger is activated by messages from IoT Core."""
IOT_BROKER_MESSAGE: TriggerType.ValueType  # 12
OBJECT_STORAGE: TriggerType.ValueType  # 5
CONTAINER_REGISTRY: TriggerType.ValueType  # 6
CLOUD_LOGS: TriggerType.ValueType  # 7
"""The trigger is activated by cloud log group events"""
LOGGING: TriggerType.ValueType  # 8
"""The trigger is activated by logging group events"""
BILLING_BUDGET: TriggerType.ValueType  # 9
"""The trigger is activated by billing events"""
YDS: TriggerType.ValueType  # 10
"""The trigger is activated by YDS events"""
MAIL: TriggerType.ValueType  # 11
"""The trigger is activated by email"""
global___TriggerType = TriggerType

@typing.final
class Trigger(google.protobuf.message.Message):
    """A trigger to invoke a serverless function. For more information, see [Triggers](/docs/functions/concepts/trigger)."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _ObjectStorageEventType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ObjectStorageEventTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Trigger._ObjectStorageEventType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        OBJECT_STORAGE_EVENT_TYPE_UNSPECIFIED: Trigger._ObjectStorageEventType.ValueType  # 0
        OBJECT_STORAGE_EVENT_TYPE_CREATE_OBJECT: Trigger._ObjectStorageEventType.ValueType  # 1
        OBJECT_STORAGE_EVENT_TYPE_UPDATE_OBJECT: Trigger._ObjectStorageEventType.ValueType  # 2
        OBJECT_STORAGE_EVENT_TYPE_DELETE_OBJECT: Trigger._ObjectStorageEventType.ValueType  # 3

    class ObjectStorageEventType(_ObjectStorageEventType, metaclass=_ObjectStorageEventTypeEnumTypeWrapper): ...
    OBJECT_STORAGE_EVENT_TYPE_UNSPECIFIED: Trigger.ObjectStorageEventType.ValueType  # 0
    OBJECT_STORAGE_EVENT_TYPE_CREATE_OBJECT: Trigger.ObjectStorageEventType.ValueType  # 1
    OBJECT_STORAGE_EVENT_TYPE_UPDATE_OBJECT: Trigger.ObjectStorageEventType.ValueType  # 2
    OBJECT_STORAGE_EVENT_TYPE_DELETE_OBJECT: Trigger.ObjectStorageEventType.ValueType  # 3

    class _ContainerRegistryEventType:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _ContainerRegistryEventTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Trigger._ContainerRegistryEventType.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        CONTAINER_REGISTRY_EVENT_TYPE_UNSPECIFIED: Trigger._ContainerRegistryEventType.ValueType  # 0
        CONTAINER_REGISTRY_EVENT_TYPE_CREATE_IMAGE: Trigger._ContainerRegistryEventType.ValueType  # 1
        CONTAINER_REGISTRY_EVENT_TYPE_DELETE_IMAGE: Trigger._ContainerRegistryEventType.ValueType  # 2
        CONTAINER_REGISTRY_EVENT_TYPE_CREATE_IMAGE_TAG: Trigger._ContainerRegistryEventType.ValueType  # 3
        CONTAINER_REGISTRY_EVENT_TYPE_DELETE_IMAGE_TAG: Trigger._ContainerRegistryEventType.ValueType  # 4

    class ContainerRegistryEventType(_ContainerRegistryEventType, metaclass=_ContainerRegistryEventTypeEnumTypeWrapper): ...
    CONTAINER_REGISTRY_EVENT_TYPE_UNSPECIFIED: Trigger.ContainerRegistryEventType.ValueType  # 0
    CONTAINER_REGISTRY_EVENT_TYPE_CREATE_IMAGE: Trigger.ContainerRegistryEventType.ValueType  # 1
    CONTAINER_REGISTRY_EVENT_TYPE_DELETE_IMAGE: Trigger.ContainerRegistryEventType.ValueType  # 2
    CONTAINER_REGISTRY_EVENT_TYPE_CREATE_IMAGE_TAG: Trigger.ContainerRegistryEventType.ValueType  # 3
    CONTAINER_REGISTRY_EVENT_TYPE_DELETE_IMAGE_TAG: Trigger.ContainerRegistryEventType.ValueType  # 4

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Trigger._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: Trigger._Status.ValueType  # 0
        ACTIVE: Trigger._Status.ValueType  # 1
        PAUSED: Trigger._Status.ValueType  # 2

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNSPECIFIED: Trigger.Status.ValueType  # 0
    ACTIVE: Trigger.Status.ValueType  # 1
    PAUSED: Trigger.Status.ValueType  # 2

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing.final
    class Rule(google.protobuf.message.Message):
        """Description of a rule for trigger activation."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        TIMER_FIELD_NUMBER: builtins.int
        MESSAGE_QUEUE_FIELD_NUMBER: builtins.int
        IOT_MESSAGE_FIELD_NUMBER: builtins.int
        IOT_BROKER_MESSAGE_FIELD_NUMBER: builtins.int
        OBJECT_STORAGE_FIELD_NUMBER: builtins.int
        CONTAINER_REGISTRY_FIELD_NUMBER: builtins.int
        CLOUD_LOGS_FIELD_NUMBER: builtins.int
        LOGGING_FIELD_NUMBER: builtins.int
        BILLING_BUDGET_FIELD_NUMBER: builtins.int
        DATA_STREAM_FIELD_NUMBER: builtins.int
        MAIL_FIELD_NUMBER: builtins.int
        @property
        def timer(self) -> global___Trigger.Timer:
            """Rule for a timed trigger."""

        @property
        def message_queue(self) -> global___Trigger.MessageQueue:
            """Rule for a message queue trigger."""

        @property
        def iot_message(self) -> global___Trigger.IoTMessage:
            """Rule for a IoT Core trigger."""

        @property
        def iot_broker_message(self) -> global___Trigger.IoTBrokerMessage: ...
        @property
        def object_storage(self) -> global___Trigger.ObjectStorage: ...
        @property
        def container_registry(self) -> global___Trigger.ContainerRegistry: ...
        @property
        def cloud_logs(self) -> global___Trigger.CloudLogs: ...
        @property
        def logging(self) -> global___Trigger.Logging: ...
        @property
        def billing_budget(self) -> global___BillingBudget: ...
        @property
        def data_stream(self) -> global___DataStream: ...
        @property
        def mail(self) -> global___Mail: ...
        def __init__(
            self,
            *,
            timer: global___Trigger.Timer | None = ...,
            message_queue: global___Trigger.MessageQueue | None = ...,
            iot_message: global___Trigger.IoTMessage | None = ...,
            iot_broker_message: global___Trigger.IoTBrokerMessage | None = ...,
            object_storage: global___Trigger.ObjectStorage | None = ...,
            container_registry: global___Trigger.ContainerRegistry | None = ...,
            cloud_logs: global___Trigger.CloudLogs | None = ...,
            logging: global___Trigger.Logging | None = ...,
            billing_budget: global___BillingBudget | None = ...,
            data_stream: global___DataStream | None = ...,
            mail: global___Mail | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["billing_budget", b"billing_budget", "cloud_logs", b"cloud_logs", "container_registry", b"container_registry", "data_stream", b"data_stream", "iot_broker_message", b"iot_broker_message", "iot_message", b"iot_message", "logging", b"logging", "mail", b"mail", "message_queue", b"message_queue", "object_storage", b"object_storage", "rule", b"rule", "timer", b"timer"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["billing_budget", b"billing_budget", "cloud_logs", b"cloud_logs", "container_registry", b"container_registry", "data_stream", b"data_stream", "iot_broker_message", b"iot_broker_message", "iot_message", b"iot_message", "logging", b"logging", "mail", b"mail", "message_queue", b"message_queue", "object_storage", b"object_storage", "rule", b"rule", "timer", b"timer"]) -> None: ...
        def WhichOneof(self, oneof_group: typing.Literal["rule", b"rule"]) -> typing.Literal["timer", "message_queue", "iot_message", "iot_broker_message", "object_storage", "container_registry", "cloud_logs", "logging", "billing_budget", "data_stream", "mail"] | None: ...

    @typing.final
    class Timer(google.protobuf.message.Message):
        """Rule for activating a timed trigger."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        CRON_EXPRESSION_FIELD_NUMBER: builtins.int
        PAYLOAD_FIELD_NUMBER: builtins.int
        INVOKE_FUNCTION_FIELD_NUMBER: builtins.int
        INVOKE_FUNCTION_WITH_RETRY_FIELD_NUMBER: builtins.int
        INVOKE_CONTAINER_WITH_RETRY_FIELD_NUMBER: builtins.int
        GATEWAY_WEBSOCKET_BROADCAST_FIELD_NUMBER: builtins.int
        cron_expression: builtins.str
        """Description of a schedule as a [cron expression](/docs/functions/concepts/trigger/timer)."""
        payload: builtins.str
        """Payload to be passed to function."""
        @property
        def invoke_function(self) -> global___InvokeFunctionOnce:
            """Instructions for invoking a function once."""

        @property
        def invoke_function_with_retry(self) -> global___InvokeFunctionWithRetry:
            """Instructions for invoking a function with retry."""

        @property
        def invoke_container_with_retry(self) -> global___InvokeContainerWithRetry:
            """Instructions for invoking a container with retry."""

        @property
        def gateway_websocket_broadcast(self) -> global___GatewayWebsocketBroadcast:
            """Instructions for broadcasting to API gateway websocket once."""

        def __init__(
            self,
            *,
            cron_expression: builtins.str = ...,
            payload: builtins.str = ...,
            invoke_function: global___InvokeFunctionOnce | None = ...,
            invoke_function_with_retry: global___InvokeFunctionWithRetry | None = ...,
            invoke_container_with_retry: global___InvokeContainerWithRetry | None = ...,
            gateway_websocket_broadcast: global___GatewayWebsocketBroadcast | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["action", b"action", "gateway_websocket_broadcast", b"gateway_websocket_broadcast", "invoke_container_with_retry", b"invoke_container_with_retry", "invoke_function", b"invoke_function", "invoke_function_with_retry", b"invoke_function_with_retry"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["action", b"action", "cron_expression", b"cron_expression", "gateway_websocket_broadcast", b"gateway_websocket_broadcast", "invoke_container_with_retry", b"invoke_container_with_retry", "invoke_function", b"invoke_function", "invoke_function_with_retry", b"invoke_function_with_retry", "payload", b"payload"]) -> None: ...
        def WhichOneof(self, oneof_group: typing.Literal["action", b"action"]) -> typing.Literal["invoke_function", "invoke_function_with_retry", "invoke_container_with_retry", "gateway_websocket_broadcast"] | None: ...

    @typing.final
    class MessageQueue(google.protobuf.message.Message):
        """Rule for activating a message queue trigger."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        QUEUE_ID_FIELD_NUMBER: builtins.int
        SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
        BATCH_SETTINGS_FIELD_NUMBER: builtins.int
        VISIBILITY_TIMEOUT_FIELD_NUMBER: builtins.int
        INVOKE_FUNCTION_FIELD_NUMBER: builtins.int
        INVOKE_CONTAINER_FIELD_NUMBER: builtins.int
        GATEWAY_WEBSOCKET_BROADCAST_FIELD_NUMBER: builtins.int
        queue_id: builtins.str
        """ID of the message queue in Message Queue."""
        service_account_id: builtins.str
        """ID of the service account which has read access to the message queue."""
        @property
        def batch_settings(self) -> global___BatchSettings:
            """Batch settings for processing messages in the queue."""

        @property
        def visibility_timeout(self) -> google.protobuf.duration_pb2.Duration:
            """Queue visibility timeout override."""

        @property
        def invoke_function(self) -> global___InvokeFunctionOnce:
            """Instructions for invoking a function once."""

        @property
        def invoke_container(self) -> global___InvokeContainerOnce:
            """Instructions for invoking a container once."""

        @property
        def gateway_websocket_broadcast(self) -> global___GatewayWebsocketBroadcast:
            """Instructions for broadcasting to API gateway websocket once."""

        def __init__(
            self,
            *,
            queue_id: builtins.str = ...,
            service_account_id: builtins.str = ...,
            batch_settings: global___BatchSettings | None = ...,
            visibility_timeout: google.protobuf.duration_pb2.Duration | None = ...,
            invoke_function: global___InvokeFunctionOnce | None = ...,
            invoke_container: global___InvokeContainerOnce | None = ...,
            gateway_websocket_broadcast: global___GatewayWebsocketBroadcast | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["action", b"action", "batch_settings", b"batch_settings", "gateway_websocket_broadcast", b"gateway_websocket_broadcast", "invoke_container", b"invoke_container", "invoke_function", b"invoke_function", "visibility_timeout", b"visibility_timeout"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["action", b"action", "batch_settings", b"batch_settings", "gateway_websocket_broadcast", b"gateway_websocket_broadcast", "invoke_container", b"invoke_container", "invoke_function", b"invoke_function", "queue_id", b"queue_id", "service_account_id", b"service_account_id", "visibility_timeout", b"visibility_timeout"]) -> None: ...
        def WhichOneof(self, oneof_group: typing.Literal["action", b"action"]) -> typing.Literal["invoke_function", "invoke_container", "gateway_websocket_broadcast"] | None: ...

    @typing.final
    class IoTMessage(google.protobuf.message.Message):
        """Rule for activating a IoT Core trigger."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        REGISTRY_ID_FIELD_NUMBER: builtins.int
        DEVICE_ID_FIELD_NUMBER: builtins.int
        MQTT_TOPIC_FIELD_NUMBER: builtins.int
        BATCH_SETTINGS_FIELD_NUMBER: builtins.int
        INVOKE_FUNCTION_FIELD_NUMBER: builtins.int
        INVOKE_CONTAINER_FIELD_NUMBER: builtins.int
        GATEWAY_WEBSOCKET_BROADCAST_FIELD_NUMBER: builtins.int
        registry_id: builtins.str
        """ID of the IoT Core registry."""
        device_id: builtins.str
        """ID of the IoT Core device in the registry."""
        mqtt_topic: builtins.str
        """MQTT topic whose messages activate the trigger."""
        @property
        def batch_settings(self) -> global___BatchSettings:
            """Batch settings for processing events."""

        @property
        def invoke_function(self) -> global___InvokeFunctionWithRetry:
            """Instructions for invoking a function with retries as needed."""

        @property
        def invoke_container(self) -> global___InvokeContainerWithRetry:
            """Instructions for invoking a container with retries as needed."""

        @property
        def gateway_websocket_broadcast(self) -> global___GatewayWebsocketBroadcast:
            """Instructions for broadcasting to API gateway websocket once."""

        def __init__(
            self,
            *,
            registry_id: builtins.str = ...,
            device_id: builtins.str = ...,
            mqtt_topic: builtins.str = ...,
            batch_settings: global___BatchSettings | None = ...,
            invoke_function: global___InvokeFunctionWithRetry | None = ...,
            invoke_container: global___InvokeContainerWithRetry | None = ...,
            gateway_websocket_broadcast: global___GatewayWebsocketBroadcast | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["action", b"action", "batch_settings", b"batch_settings", "gateway_websocket_broadcast", b"gateway_websocket_broadcast", "invoke_container", b"invoke_container", "invoke_function", b"invoke_function"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["action", b"action", "batch_settings", b"batch_settings", "device_id", b"device_id", "gateway_websocket_broadcast", b"gateway_websocket_broadcast", "invoke_container", b"invoke_container", "invoke_function", b"invoke_function", "mqtt_topic", b"mqtt_topic", "registry_id", b"registry_id"]) -> None: ...
        def WhichOneof(self, oneof_group: typing.Literal["action", b"action"]) -> typing.Literal["invoke_function", "invoke_container", "gateway_websocket_broadcast"] | None: ...

    @typing.final
    class IoTBrokerMessage(google.protobuf.message.Message):
        """Rule for activating a IoT Core Broker trigger."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        BROKER_ID_FIELD_NUMBER: builtins.int
        MQTT_TOPIC_FIELD_NUMBER: builtins.int
        BATCH_SETTINGS_FIELD_NUMBER: builtins.int
        INVOKE_FUNCTION_FIELD_NUMBER: builtins.int
        INVOKE_CONTAINER_FIELD_NUMBER: builtins.int
        GATEWAY_WEBSOCKET_BROADCAST_FIELD_NUMBER: builtins.int
        broker_id: builtins.str
        """ID of the IoT Core broker."""
        mqtt_topic: builtins.str
        """MQTT topic whose messages activate the trigger."""
        @property
        def batch_settings(self) -> global___BatchSettings:
            """Batch settings for processing events."""

        @property
        def invoke_function(self) -> global___InvokeFunctionWithRetry:
            """Instructions for invoking a function with retries as needed."""

        @property
        def invoke_container(self) -> global___InvokeContainerWithRetry:
            """Instructions for invoking a container with retries as needed."""

        @property
        def gateway_websocket_broadcast(self) -> global___GatewayWebsocketBroadcast:
            """Instructions for broadcasting to API gateway websocket once."""

        def __init__(
            self,
            *,
            broker_id: builtins.str = ...,
            mqtt_topic: builtins.str = ...,
            batch_settings: global___BatchSettings | None = ...,
            invoke_function: global___InvokeFunctionWithRetry | None = ...,
            invoke_container: global___InvokeContainerWithRetry | None = ...,
            gateway_websocket_broadcast: global___GatewayWebsocketBroadcast | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["action", b"action", "batch_settings", b"batch_settings", "gateway_websocket_broadcast", b"gateway_websocket_broadcast", "invoke_container", b"invoke_container", "invoke_function", b"invoke_function"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["action", b"action", "batch_settings", b"batch_settings", "broker_id", b"broker_id", "gateway_websocket_broadcast", b"gateway_websocket_broadcast", "invoke_container", b"invoke_container", "invoke_function", b"invoke_function", "mqtt_topic", b"mqtt_topic"]) -> None: ...
        def WhichOneof(self, oneof_group: typing.Literal["action", b"action"]) -> typing.Literal["invoke_function", "invoke_container", "gateway_websocket_broadcast"] | None: ...

    @typing.final
    class ObjectStorage(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        EVENT_TYPE_FIELD_NUMBER: builtins.int
        BUCKET_ID_FIELD_NUMBER: builtins.int
        PREFIX_FIELD_NUMBER: builtins.int
        SUFFIX_FIELD_NUMBER: builtins.int
        BATCH_SETTINGS_FIELD_NUMBER: builtins.int
        INVOKE_FUNCTION_FIELD_NUMBER: builtins.int
        INVOKE_CONTAINER_FIELD_NUMBER: builtins.int
        GATEWAY_WEBSOCKET_BROADCAST_FIELD_NUMBER: builtins.int
        bucket_id: builtins.str
        """ID of the bucket."""
        prefix: builtins.str
        """Prefix of the object key. Filter, optional."""
        suffix: builtins.str
        """Suffix of the object key. Filter, optional."""
        @property
        def event_type(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[global___Trigger.ObjectStorageEventType.ValueType]:
            """Type (name) of events, at least one value is required."""

        @property
        def batch_settings(self) -> global___BatchSettings:
            """Batch settings for processing events."""

        @property
        def invoke_function(self) -> global___InvokeFunctionWithRetry:
            """Instructions for invoking a function with retries as needed."""

        @property
        def invoke_container(self) -> global___InvokeContainerWithRetry:
            """Instructions for invoking a container with retries as needed."""

        @property
        def gateway_websocket_broadcast(self) -> global___GatewayWebsocketBroadcast:
            """Instructions for broadcasting to API gateway websocket once."""

        def __init__(
            self,
            *,
            event_type: collections.abc.Iterable[global___Trigger.ObjectStorageEventType.ValueType] | None = ...,
            bucket_id: builtins.str = ...,
            prefix: builtins.str = ...,
            suffix: builtins.str = ...,
            batch_settings: global___BatchSettings | None = ...,
            invoke_function: global___InvokeFunctionWithRetry | None = ...,
            invoke_container: global___InvokeContainerWithRetry | None = ...,
            gateway_websocket_broadcast: global___GatewayWebsocketBroadcast | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["action", b"action", "batch_settings", b"batch_settings", "gateway_websocket_broadcast", b"gateway_websocket_broadcast", "invoke_container", b"invoke_container", "invoke_function", b"invoke_function"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["action", b"action", "batch_settings", b"batch_settings", "bucket_id", b"bucket_id", "event_type", b"event_type", "gateway_websocket_broadcast", b"gateway_websocket_broadcast", "invoke_container", b"invoke_container", "invoke_function", b"invoke_function", "prefix", b"prefix", "suffix", b"suffix"]) -> None: ...
        def WhichOneof(self, oneof_group: typing.Literal["action", b"action"]) -> typing.Literal["invoke_function", "invoke_container", "gateway_websocket_broadcast"] | None: ...

    @typing.final
    class ContainerRegistry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        EVENT_TYPE_FIELD_NUMBER: builtins.int
        REGISTRY_ID_FIELD_NUMBER: builtins.int
        IMAGE_NAME_FIELD_NUMBER: builtins.int
        TAG_FIELD_NUMBER: builtins.int
        BATCH_SETTINGS_FIELD_NUMBER: builtins.int
        INVOKE_FUNCTION_FIELD_NUMBER: builtins.int
        INVOKE_CONTAINER_FIELD_NUMBER: builtins.int
        GATEWAY_WEBSOCKET_BROADCAST_FIELD_NUMBER: builtins.int
        registry_id: builtins.str
        """ID of the registry."""
        image_name: builtins.str
        """Docker-image name. Filter, optional."""
        tag: builtins.str
        """Docker-image tag. Filter, optional."""
        @property
        def event_type(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[global___Trigger.ContainerRegistryEventType.ValueType]:
            """Type (name) of events, at least one value is required."""

        @property
        def batch_settings(self) -> global___BatchSettings:
            """Batch settings for processing events."""

        @property
        def invoke_function(self) -> global___InvokeFunctionWithRetry:
            """Instructions for invoking a function with retries as needed."""

        @property
        def invoke_container(self) -> global___InvokeContainerWithRetry:
            """Instructions for invoking a container with retries as needed."""

        @property
        def gateway_websocket_broadcast(self) -> global___GatewayWebsocketBroadcast:
            """Instructions for broadcasting to API gateway websocket once."""

        def __init__(
            self,
            *,
            event_type: collections.abc.Iterable[global___Trigger.ContainerRegistryEventType.ValueType] | None = ...,
            registry_id: builtins.str = ...,
            image_name: builtins.str = ...,
            tag: builtins.str = ...,
            batch_settings: global___BatchSettings | None = ...,
            invoke_function: global___InvokeFunctionWithRetry | None = ...,
            invoke_container: global___InvokeContainerWithRetry | None = ...,
            gateway_websocket_broadcast: global___GatewayWebsocketBroadcast | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["action", b"action", "batch_settings", b"batch_settings", "gateway_websocket_broadcast", b"gateway_websocket_broadcast", "invoke_container", b"invoke_container", "invoke_function", b"invoke_function"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["action", b"action", "batch_settings", b"batch_settings", "event_type", b"event_type", "gateway_websocket_broadcast", b"gateway_websocket_broadcast", "image_name", b"image_name", "invoke_container", b"invoke_container", "invoke_function", b"invoke_function", "registry_id", b"registry_id", "tag", b"tag"]) -> None: ...
        def WhichOneof(self, oneof_group: typing.Literal["action", b"action"]) -> typing.Literal["invoke_function", "invoke_container", "gateway_websocket_broadcast"] | None: ...

    @typing.final
    class CloudLogs(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        LOG_GROUP_ID_FIELD_NUMBER: builtins.int
        BATCH_SETTINGS_FIELD_NUMBER: builtins.int
        INVOKE_FUNCTION_FIELD_NUMBER: builtins.int
        INVOKE_CONTAINER_FIELD_NUMBER: builtins.int
        @property
        def log_group_id(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
            """Log group identifiers, at least one value is required."""

        @property
        def batch_settings(self) -> global___CloudLogsBatchSettings:
            """Batch settings for processing log events."""

        @property
        def invoke_function(self) -> global___InvokeFunctionWithRetry:
            """Instructions for invoking a function with retries as needed."""

        @property
        def invoke_container(self) -> global___InvokeContainerWithRetry:
            """Instructions for invoking a container with retries as needed."""

        def __init__(
            self,
            *,
            log_group_id: collections.abc.Iterable[builtins.str] | None = ...,
            batch_settings: global___CloudLogsBatchSettings | None = ...,
            invoke_function: global___InvokeFunctionWithRetry | None = ...,
            invoke_container: global___InvokeContainerWithRetry | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["action", b"action", "batch_settings", b"batch_settings", "invoke_container", b"invoke_container", "invoke_function", b"invoke_function"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["action", b"action", "batch_settings", b"batch_settings", "invoke_container", b"invoke_container", "invoke_function", b"invoke_function", "log_group_id", b"log_group_id"]) -> None: ...
        def WhichOneof(self, oneof_group: typing.Literal["action", b"action"]) -> typing.Literal["invoke_function", "invoke_container"] | None: ...

    @typing.final
    class Logging(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        LOG_GROUP_ID_FIELD_NUMBER: builtins.int
        RESOURCE_TYPE_FIELD_NUMBER: builtins.int
        RESOURCE_ID_FIELD_NUMBER: builtins.int
        STREAM_NAME_FIELD_NUMBER: builtins.int
        LEVELS_FIELD_NUMBER: builtins.int
        BATCH_SETTINGS_FIELD_NUMBER: builtins.int
        INVOKE_FUNCTION_FIELD_NUMBER: builtins.int
        INVOKE_CONTAINER_FIELD_NUMBER: builtins.int
        GATEWAY_WEBSOCKET_BROADCAST_FIELD_NUMBER: builtins.int
        log_group_id: builtins.str
        """Log events filter settings."""
        @property
        def resource_type(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
        @property
        def resource_id(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
        @property
        def stream_name(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
        @property
        def levels(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[yandex.cloud.logging.v1.log_entry_pb2.LogLevel.Level.ValueType]: ...
        @property
        def batch_settings(self) -> global___LoggingBatchSettings:
            """Batch settings for processing log events."""

        @property
        def invoke_function(self) -> global___InvokeFunctionWithRetry:
            """Instructions for invoking a function with retries as needed."""

        @property
        def invoke_container(self) -> global___InvokeContainerWithRetry:
            """Instructions for invoking a container with retries as needed."""

        @property
        def gateway_websocket_broadcast(self) -> global___GatewayWebsocketBroadcast:
            """Instructions for broadcasting to API gateway websocket once."""

        def __init__(
            self,
            *,
            log_group_id: builtins.str = ...,
            resource_type: collections.abc.Iterable[builtins.str] | None = ...,
            resource_id: collections.abc.Iterable[builtins.str] | None = ...,
            stream_name: collections.abc.Iterable[builtins.str] | None = ...,
            levels: collections.abc.Iterable[yandex.cloud.logging.v1.log_entry_pb2.LogLevel.Level.ValueType] | None = ...,
            batch_settings: global___LoggingBatchSettings | None = ...,
            invoke_function: global___InvokeFunctionWithRetry | None = ...,
            invoke_container: global___InvokeContainerWithRetry | None = ...,
            gateway_websocket_broadcast: global___GatewayWebsocketBroadcast | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["action", b"action", "batch_settings", b"batch_settings", "gateway_websocket_broadcast", b"gateway_websocket_broadcast", "invoke_container", b"invoke_container", "invoke_function", b"invoke_function"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["action", b"action", "batch_settings", b"batch_settings", "gateway_websocket_broadcast", b"gateway_websocket_broadcast", "invoke_container", b"invoke_container", "invoke_function", b"invoke_function", "levels", b"levels", "log_group_id", b"log_group_id", "resource_id", b"resource_id", "resource_type", b"resource_type", "stream_name", b"stream_name"]) -> None: ...
        def WhichOneof(self, oneof_group: typing.Literal["action", b"action"]) -> typing.Literal["invoke_function", "invoke_container", "gateway_websocket_broadcast"] | None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    RULE_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the trigger. Generated at creation time."""
    folder_id: builtins.str
    """ID of the folder that the trigger belongs to."""
    name: builtins.str
    """Name of the trigger."""
    description: builtins.str
    """Description of the trigger."""
    status: global___Trigger.Status.ValueType
    """Trigger status."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp for the trigger."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Trigger labels as `key:value` pairs."""

    @property
    def rule(self) -> global___Trigger.Rule:
        """Rule for trigger activation (always consistent with the trigger type)."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        rule: global___Trigger.Rule | None = ...,
        status: global___Trigger.Status.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "rule", b"rule"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["created_at", b"created_at", "description", b"description", "folder_id", b"folder_id", "id", b"id", "labels", b"labels", "name", b"name", "rule", b"rule", "status", b"status"]) -> None: ...

global___Trigger = Trigger

@typing.final
class InvokeFunctionOnce(google.protobuf.message.Message):
    """A single function invocation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FUNCTION_ID_FIELD_NUMBER: builtins.int
    FUNCTION_TAG_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    function_id: builtins.str
    """ID of the function to invoke."""
    function_tag: builtins.str
    """Version tag of the function to execute."""
    service_account_id: builtins.str
    """ID of the service account that should be used to invoke the function."""
    def __init__(
        self,
        *,
        function_id: builtins.str = ...,
        function_tag: builtins.str = ...,
        service_account_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["function_id", b"function_id", "function_tag", b"function_tag", "service_account_id", b"service_account_id"]) -> None: ...

global___InvokeFunctionOnce = InvokeFunctionOnce

@typing.final
class InvokeFunctionWithRetry(google.protobuf.message.Message):
    """A function invocation with retries."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FUNCTION_ID_FIELD_NUMBER: builtins.int
    FUNCTION_TAG_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    RETRY_SETTINGS_FIELD_NUMBER: builtins.int
    DEAD_LETTER_QUEUE_FIELD_NUMBER: builtins.int
    function_id: builtins.str
    """ID of the function to invoke."""
    function_tag: builtins.str
    """Version tag of the function to execute."""
    service_account_id: builtins.str
    """ID of the service account which has permission to invoke the function."""
    @property
    def retry_settings(self) -> global___RetrySettings:
        """Retry policy. If the field is not specified, or the value is empty, no retries will be attempted."""

    @property
    def dead_letter_queue(self) -> global___PutQueueMessage:
        """DLQ policy (no value means discarding a message)."""

    def __init__(
        self,
        *,
        function_id: builtins.str = ...,
        function_tag: builtins.str = ...,
        service_account_id: builtins.str = ...,
        retry_settings: global___RetrySettings | None = ...,
        dead_letter_queue: global___PutQueueMessage | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["dead_letter_queue", b"dead_letter_queue", "retry_settings", b"retry_settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["dead_letter_queue", b"dead_letter_queue", "function_id", b"function_id", "function_tag", b"function_tag", "retry_settings", b"retry_settings", "service_account_id", b"service_account_id"]) -> None: ...

global___InvokeFunctionWithRetry = InvokeFunctionWithRetry

@typing.final
class InvokeContainerOnce(google.protobuf.message.Message):
    """A single container invocation."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTAINER_ID_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    container_id: builtins.str
    """ID of the container to invoke."""
    path: builtins.str
    """Endpoint HTTP path to invoke."""
    service_account_id: builtins.str
    """ID of the service account which has permission to invoke the container."""
    def __init__(
        self,
        *,
        container_id: builtins.str = ...,
        path: builtins.str = ...,
        service_account_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["container_id", b"container_id", "path", b"path", "service_account_id", b"service_account_id"]) -> None: ...

global___InvokeContainerOnce = InvokeContainerOnce

@typing.final
class InvokeContainerWithRetry(google.protobuf.message.Message):
    """A container invocation with retries."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTAINER_ID_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    RETRY_SETTINGS_FIELD_NUMBER: builtins.int
    DEAD_LETTER_QUEUE_FIELD_NUMBER: builtins.int
    container_id: builtins.str
    """ID of the container to invoke."""
    path: builtins.str
    """Endpoint HTTP path to invoke."""
    service_account_id: builtins.str
    """ID of the service account which has permission to invoke the container."""
    @property
    def retry_settings(self) -> global___RetrySettings:
        """Retry policy. If the field is not specified, or the value is empty, no retries will be attempted."""

    @property
    def dead_letter_queue(self) -> global___PutQueueMessage:
        """DLQ policy (no value means discarding a message)."""

    def __init__(
        self,
        *,
        container_id: builtins.str = ...,
        path: builtins.str = ...,
        service_account_id: builtins.str = ...,
        retry_settings: global___RetrySettings | None = ...,
        dead_letter_queue: global___PutQueueMessage | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["dead_letter_queue", b"dead_letter_queue", "retry_settings", b"retry_settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["container_id", b"container_id", "dead_letter_queue", b"dead_letter_queue", "path", b"path", "retry_settings", b"retry_settings", "service_account_id", b"service_account_id"]) -> None: ...

global___InvokeContainerWithRetry = InvokeContainerWithRetry

@typing.final
class GatewayWebsocketBroadcast(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GATEWAY_ID_FIELD_NUMBER: builtins.int
    PATH_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    gateway_id: builtins.str
    path: builtins.str
    service_account_id: builtins.str
    """sa which has permission for writing to websockets"""
    def __init__(
        self,
        *,
        gateway_id: builtins.str = ...,
        path: builtins.str = ...,
        service_account_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["gateway_id", b"gateway_id", "path", b"path", "service_account_id", b"service_account_id"]) -> None: ...

global___GatewayWebsocketBroadcast = GatewayWebsocketBroadcast

@typing.final
class PutQueueMessage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    QUEUE_ID_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    queue_id: builtins.str
    """ID of the queue."""
    service_account_id: builtins.str
    """Service account which has write permission on the queue."""
    def __init__(
        self,
        *,
        queue_id: builtins.str = ...,
        service_account_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["queue_id", b"queue_id", "service_account_id", b"service_account_id"]) -> None: ...

global___PutQueueMessage = PutQueueMessage

@typing.final
class BatchSettings(google.protobuf.message.Message):
    """Settings for batch processing of messages in a queue."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SIZE_FIELD_NUMBER: builtins.int
    CUTOFF_FIELD_NUMBER: builtins.int
    size: builtins.int
    """Batch size. Trigger will send the batch of messages to the function
    when the number of messages in the queue reaches [size], or the [cutoff] time has passed.
    """
    @property
    def cutoff(self) -> google.protobuf.duration_pb2.Duration:
        """Maximum wait time. Trigger will send the batch of messages to the function when
        the number of messages in the queue reaches [size], or the [cutoff] time has passed.
        """

    def __init__(
        self,
        *,
        size: builtins.int = ...,
        cutoff: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["cutoff", b"cutoff"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cutoff", b"cutoff", "size", b"size"]) -> None: ...

global___BatchSettings = BatchSettings

@typing.final
class CloudLogsBatchSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SIZE_FIELD_NUMBER: builtins.int
    CUTOFF_FIELD_NUMBER: builtins.int
    size: builtins.int
    """Batch size. Trigger will send the batch of messages to the function
    when the number of messages in the log group reaches [size], or the [cutoff] time has passed.
    """
    @property
    def cutoff(self) -> google.protobuf.duration_pb2.Duration:
        """Maximum wait time. Trigger will send the batch of messages to the function when
        the number of messages in the log group reaches [size], or the [cutoff] time has passed.
        """

    def __init__(
        self,
        *,
        size: builtins.int = ...,
        cutoff: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["cutoff", b"cutoff"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cutoff", b"cutoff", "size", b"size"]) -> None: ...

global___CloudLogsBatchSettings = CloudLogsBatchSettings

@typing.final
class LoggingBatchSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SIZE_FIELD_NUMBER: builtins.int
    CUTOFF_FIELD_NUMBER: builtins.int
    size: builtins.int
    """Batch size. Trigger will send the batch of messages to the associated function
    when the number of log events reaches this value, or the [cutoff] time has passed.
    """
    @property
    def cutoff(self) -> google.protobuf.duration_pb2.Duration:
        """Maximum wait time. Trigger will send the batch of messages the time since the last batch
        exceeds the `cutoff` value, regardless of the amount of log events.
        """

    def __init__(
        self,
        *,
        size: builtins.int = ...,
        cutoff: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["cutoff", b"cutoff"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cutoff", b"cutoff", "size", b"size"]) -> None: ...

global___LoggingBatchSettings = LoggingBatchSettings

@typing.final
class RetrySettings(google.protobuf.message.Message):
    """Settings for retrying to invoke a function."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RETRY_ATTEMPTS_FIELD_NUMBER: builtins.int
    INTERVAL_FIELD_NUMBER: builtins.int
    retry_attempts: builtins.int
    """Maximum number of retries (extra invokes) before the action is considered failed."""
    @property
    def interval(self) -> google.protobuf.duration_pb2.Duration:
        """Time in seconds to wait between individual retries."""

    def __init__(
        self,
        *,
        retry_attempts: builtins.int = ...,
        interval: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["interval", b"interval"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["interval", b"interval", "retry_attempts", b"retry_attempts"]) -> None: ...

global___RetrySettings = RetrySettings

@typing.final
class BillingBudget(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BILLING_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    BUDGET_ID_FIELD_NUMBER: builtins.int
    INVOKE_FUNCTION_FIELD_NUMBER: builtins.int
    INVOKE_CONTAINER_FIELD_NUMBER: builtins.int
    GATEWAY_WEBSOCKET_BROADCAST_FIELD_NUMBER: builtins.int
    billing_account_id: builtins.str
    budget_id: builtins.str
    @property
    def invoke_function(self) -> global___InvokeFunctionWithRetry: ...
    @property
    def invoke_container(self) -> global___InvokeContainerWithRetry: ...
    @property
    def gateway_websocket_broadcast(self) -> global___GatewayWebsocketBroadcast: ...
    def __init__(
        self,
        *,
        billing_account_id: builtins.str = ...,
        budget_id: builtins.str = ...,
        invoke_function: global___InvokeFunctionWithRetry | None = ...,
        invoke_container: global___InvokeContainerWithRetry | None = ...,
        gateway_websocket_broadcast: global___GatewayWebsocketBroadcast | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["action", b"action", "gateway_websocket_broadcast", b"gateway_websocket_broadcast", "invoke_container", b"invoke_container", "invoke_function", b"invoke_function"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["action", b"action", "billing_account_id", b"billing_account_id", "budget_id", b"budget_id", "gateway_websocket_broadcast", b"gateway_websocket_broadcast", "invoke_container", b"invoke_container", "invoke_function", b"invoke_function"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["action", b"action"]) -> typing.Literal["invoke_function", "invoke_container", "gateway_websocket_broadcast"] | None: ...

global___BillingBudget = BillingBudget

@typing.final
class DataStreamBatchSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SIZE_FIELD_NUMBER: builtins.int
    CUTOFF_FIELD_NUMBER: builtins.int
    size: builtins.int
    """Batch size in bytes. Trigger will send the batch of messages to the associated function
    when size of log events reaches this value, or the [cutoff] time has passed.
    """
    @property
    def cutoff(self) -> google.protobuf.duration_pb2.Duration:
        """Maximum wait time. Trigger will send the batch of messages the time since the last batch
        exceeds the `cutoff` value, regardless of the amount of log events.
        """

    def __init__(
        self,
        *,
        size: builtins.int = ...,
        cutoff: google.protobuf.duration_pb2.Duration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["cutoff", b"cutoff"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cutoff", b"cutoff", "size", b"size"]) -> None: ...

global___DataStreamBatchSettings = DataStreamBatchSettings

@typing.final
class DataStream(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENDPOINT_FIELD_NUMBER: builtins.int
    DATABASE_FIELD_NUMBER: builtins.int
    STREAM_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    BATCH_SETTINGS_FIELD_NUMBER: builtins.int
    INVOKE_FUNCTION_FIELD_NUMBER: builtins.int
    INVOKE_CONTAINER_FIELD_NUMBER: builtins.int
    GATEWAY_WEBSOCKET_BROADCAST_FIELD_NUMBER: builtins.int
    endpoint: builtins.str
    """Data stream endpoint."""
    database: builtins.str
    """Data stream database."""
    stream: builtins.str
    """Stream name."""
    service_account_id: builtins.str
    """ID of the service account which has permission to read data stream."""
    @property
    def batch_settings(self) -> global___DataStreamBatchSettings:
        """Batch settings for processing events."""

    @property
    def invoke_function(self) -> global___InvokeFunctionWithRetry: ...
    @property
    def invoke_container(self) -> global___InvokeContainerWithRetry: ...
    @property
    def gateway_websocket_broadcast(self) -> global___GatewayWebsocketBroadcast: ...
    def __init__(
        self,
        *,
        endpoint: builtins.str = ...,
        database: builtins.str = ...,
        stream: builtins.str = ...,
        service_account_id: builtins.str = ...,
        batch_settings: global___DataStreamBatchSettings | None = ...,
        invoke_function: global___InvokeFunctionWithRetry | None = ...,
        invoke_container: global___InvokeContainerWithRetry | None = ...,
        gateway_websocket_broadcast: global___GatewayWebsocketBroadcast | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["action", b"action", "batch_settings", b"batch_settings", "gateway_websocket_broadcast", b"gateway_websocket_broadcast", "invoke_container", b"invoke_container", "invoke_function", b"invoke_function"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["action", b"action", "batch_settings", b"batch_settings", "database", b"database", "endpoint", b"endpoint", "gateway_websocket_broadcast", b"gateway_websocket_broadcast", "invoke_container", b"invoke_container", "invoke_function", b"invoke_function", "service_account_id", b"service_account_id", "stream", b"stream"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["action", b"action"]) -> typing.Literal["invoke_function", "invoke_container", "gateway_websocket_broadcast"] | None: ...

global___DataStream = DataStream

@typing.final
class ObjectStorageBucketSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUCKET_ID_FIELD_NUMBER: builtins.int
    SERVICE_ACCOUNT_ID_FIELD_NUMBER: builtins.int
    bucket_id: builtins.str
    """Bucket for saving."""
    service_account_id: builtins.str
    """SA which has write permission on storage."""
    def __init__(
        self,
        *,
        bucket_id: builtins.str = ...,
        service_account_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["bucket_id", b"bucket_id", "service_account_id", b"service_account_id"]) -> None: ...

global___ObjectStorageBucketSettings = ObjectStorageBucketSettings

@typing.final
class Mail(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EMAIL_FIELD_NUMBER: builtins.int
    BATCH_SETTINGS_FIELD_NUMBER: builtins.int
    ATTACHMENTS_BUCKET_FIELD_NUMBER: builtins.int
    INVOKE_FUNCTION_FIELD_NUMBER: builtins.int
    INVOKE_CONTAINER_FIELD_NUMBER: builtins.int
    GATEWAY_WEBSOCKET_BROADCAST_FIELD_NUMBER: builtins.int
    email: builtins.str
    """Address to receive emails for trigger activation.
    Field is ignored for write requests and populated on trigger creation.
    """
    @property
    def batch_settings(self) -> global___BatchSettings:
        """Batch settings for processing events."""

    @property
    def attachments_bucket(self) -> global___ObjectStorageBucketSettings:
        """Bucket settings for saving attachments."""

    @property
    def invoke_function(self) -> global___InvokeFunctionWithRetry: ...
    @property
    def invoke_container(self) -> global___InvokeContainerWithRetry: ...
    @property
    def gateway_websocket_broadcast(self) -> global___GatewayWebsocketBroadcast: ...
    def __init__(
        self,
        *,
        email: builtins.str = ...,
        batch_settings: global___BatchSettings | None = ...,
        attachments_bucket: global___ObjectStorageBucketSettings | None = ...,
        invoke_function: global___InvokeFunctionWithRetry | None = ...,
        invoke_container: global___InvokeContainerWithRetry | None = ...,
        gateway_websocket_broadcast: global___GatewayWebsocketBroadcast | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["action", b"action", "attachments_bucket", b"attachments_bucket", "batch_settings", b"batch_settings", "gateway_websocket_broadcast", b"gateway_websocket_broadcast", "invoke_container", b"invoke_container", "invoke_function", b"invoke_function"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["action", b"action", "attachments_bucket", b"attachments_bucket", "batch_settings", b"batch_settings", "email", b"email", "gateway_websocket_broadcast", b"gateway_websocket_broadcast", "invoke_container", b"invoke_container", "invoke_function", b"invoke_function"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["action", b"action"]) -> typing.Literal["invoke_function", "invoke_container", "gateway_websocket_broadcast"] | None: ...

global___Mail = Mail



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.cdn.v1.origin_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class OriginGroup(google.protobuf.message.Message):
    """Origin group parameters. For details about the concept, see [documentation](/docs/cdn/concepts/origins#groups)."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    USE_NEXT_FIELD_NUMBER: builtins.int
    ORIGINS_FIELD_NUMBER: builtins.int
    id: builtins.int
    """ID of the origin group. Generated at creation time."""
    folder_id: builtins.str
    """ID of the folder that the origin group belongs to."""
    name: builtins.str
    """Name of the origin group."""
    use_next: builtins.bool
    """This option have two possible conditions:
    true - the option is active. In case the origin responds with 4XX or 5XX codes,
           use the next origin from the list.
    false - the option is disabled.
    """
    @property
    def origins(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.cdn.v1.origin_pb2.Origin]:
        """List of origins."""

    def __init__(
        self,
        *,
        id: builtins.int = ...,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        use_next: builtins.bool = ...,
        origins: collections.abc.Iterable[yandex.cloud.cdn.v1.origin_pb2.Origin] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id", "id", b"id", "name", b"name", "origins", b"origins", "use_next", b"use_next"]) -> None: ...

global___OriginGroup = OriginGroup



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing
import yandex.cloud.compute.v1.host_group_pb2
import yandex.cloud.compute.v1.instance_pb2
import yandex.cloud.compute.v1.maintenance_pb2
import yandex.cloud.operation.operation_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetHostGroupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_GROUP_ID_FIELD_NUMBER: builtins.int
    host_group_id: builtins.str
    """ID of the host group to return.
    To get the host group ID, use [HostGroupService.List] request.
    """
    def __init__(
        self,
        *,
        host_group_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["host_group_id", b"host_group_id"]) -> None: ...

global___GetHostGroupRequest = GetHostGroupRequest

@typing.final
class ListHostGroupsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    ORDER_BY_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to list host groups in.
    To get the folder ID, use [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListHostGroupsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token. To get the next page of results,
    set [page_token] to the [ListHostGroupsResponse.next_page_token]
    returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.
    The expression consists of one or more conditions united by `AND` operator: `<condition1> [AND <condition2> [<...> AND <conditionN>]]`.

    Each condition has the form `<field> <operator> <value>`, where:
    1. `<field>` is the field name. Currently you can use filtering only on the limited number of fields.
    2. `<operator>` is a logical operator, one of `=`, `!=`, `IN`, `NOT IN`.
    3. `<value>` represents a value.
    String values should be written in double (`"`) or single (`'`) quotes. C-style escape sequences are supported (`\\"` turns to `"`, `\\'` to `'`, `\\\\` to backslash).
    """
    order_by: builtins.str
    """By which column the listing should be ordered and in which direction,
    format is "createdAt desc". "id asc" if omitted.
    The default sorting order is ascending
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
        order_by: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "folder_id", b"folder_id", "order_by", b"order_by", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListHostGroupsRequest = ListHostGroupsRequest

@typing.final
class ListHostGroupsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_GROUPS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListHostGroupsRequest.page_size], use
    [next_page_token] as the value
    for the [ListHostGroupsRequest.page_token] query parameter
    in the next list request. Each subsequent list request will have its own
    [next_page_token] to continue paging through the results.
    """
    @property
    def host_groups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.compute.v1.host_group_pb2.HostGroup]:
        """Lists host groups for the specified folder."""

    def __init__(
        self,
        *,
        host_groups: collections.abc.Iterable[yandex.cloud.compute.v1.host_group_pb2.HostGroup] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["host_groups", b"host_groups", "next_page_token", b"next_page_token"]) -> None: ...

global___ListHostGroupsResponse = ListHostGroupsResponse

@typing.final
class CreateHostGroupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    FOLDER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    ZONE_ID_FIELD_NUMBER: builtins.int
    TYPE_ID_FIELD_NUMBER: builtins.int
    MAINTENANCE_POLICY_FIELD_NUMBER: builtins.int
    SCALE_POLICY_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to create a host group in.
    To get the folder ID, use a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    name: builtins.str
    """Name of the group."""
    description: builtins.str
    """Description of the group."""
    zone_id: builtins.str
    """Availability zone where all dedicated hosts will be allocated."""
    type_id: builtins.str
    """ID of host type. Resources provided by each host of the group."""
    maintenance_policy: yandex.cloud.compute.v1.maintenance_pb2.MaintenancePolicy.ValueType
    """Behaviour on maintenance events."""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs."""

    @property
    def scale_policy(self) -> yandex.cloud.compute.v1.host_group_pb2.ScalePolicy:
        """Scale policy. Only fixed number of hosts are supported at this moment."""

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        zone_id: builtins.str = ...,
        type_id: builtins.str = ...,
        maintenance_policy: yandex.cloud.compute.v1.maintenance_pb2.MaintenancePolicy.ValueType = ...,
        scale_policy: yandex.cloud.compute.v1.host_group_pb2.ScalePolicy | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["scale_policy", b"scale_policy"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "folder_id", b"folder_id", "labels", b"labels", "maintenance_policy", b"maintenance_policy", "name", b"name", "scale_policy", b"scale_policy", "type_id", b"type_id", "zone_id", b"zone_id"]) -> None: ...

global___CreateHostGroupRequest = CreateHostGroupRequest

@typing.final
class CreateHostGroupMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_GROUP_ID_FIELD_NUMBER: builtins.int
    host_group_id: builtins.str
    """ID of the host group that is being created."""
    def __init__(
        self,
        *,
        host_group_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["host_group_id", b"host_group_id"]) -> None: ...

global___CreateHostGroupMetadata = CreateHostGroupMetadata

@typing.final
class UpdateHostGroupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    HOST_GROUP_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    MAINTENANCE_POLICY_FIELD_NUMBER: builtins.int
    SCALE_POLICY_FIELD_NUMBER: builtins.int
    host_group_id: builtins.str
    """ID of the host group to update.
    To get the host group ID, use an [HostGroupService.List] request.
    """
    name: builtins.str
    """Name of the group."""
    description: builtins.str
    """Description of the group."""
    maintenance_policy: yandex.cloud.compute.v1.maintenance_pb2.MaintenancePolicy.ValueType
    """Behaviour on maintenance events"""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which fields of the HostGroup resource are going to be updated."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs.

        The existing set of `labels` is completely replaced by the provided set.
        """

    @property
    def scale_policy(self) -> yandex.cloud.compute.v1.host_group_pb2.ScalePolicy:
        """Scale policy. Only fixed number of hosts are supported at this moment."""

    def __init__(
        self,
        *,
        host_group_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        maintenance_policy: yandex.cloud.compute.v1.maintenance_pb2.MaintenancePolicy.ValueType = ...,
        scale_policy: yandex.cloud.compute.v1.host_group_pb2.ScalePolicy | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["scale_policy", b"scale_policy", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "host_group_id", b"host_group_id", "labels", b"labels", "maintenance_policy", b"maintenance_policy", "name", b"name", "scale_policy", b"scale_policy", "update_mask", b"update_mask"]) -> None: ...

global___UpdateHostGroupRequest = UpdateHostGroupRequest

@typing.final
class UpdateHostGroupMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_GROUP_ID_FIELD_NUMBER: builtins.int
    host_group_id: builtins.str
    """ID of the host group that is being updated."""
    def __init__(
        self,
        *,
        host_group_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["host_group_id", b"host_group_id"]) -> None: ...

global___UpdateHostGroupMetadata = UpdateHostGroupMetadata

@typing.final
class DeleteHostGroupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_GROUP_ID_FIELD_NUMBER: builtins.int
    host_group_id: builtins.str
    """ID of the host group to delete.
    To get the host group ID, use [HostGroupService.List] request.
    """
    def __init__(
        self,
        *,
        host_group_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["host_group_id", b"host_group_id"]) -> None: ...

global___DeleteHostGroupRequest = DeleteHostGroupRequest

@typing.final
class DeleteHostGroupMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_GROUP_ID_FIELD_NUMBER: builtins.int
    host_group_id: builtins.str
    """ID of the host group that is being deleted."""
    def __init__(
        self,
        *,
        host_group_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["host_group_id", b"host_group_id"]) -> None: ...

global___DeleteHostGroupMetadata = DeleteHostGroupMetadata

@typing.final
class ListHostGroupInstancesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_GROUP_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    host_group_id: builtins.str
    """ID of the host group to list instances for.
    To get the host group ID, use [HostGroupService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListHostGroupInstancesResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token. To get the next page of results,
    set [page_token] to the [ListHostGroupInstancesResponse.next_page_token]
    returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.
    The expression consists of one or more conditions united by `AND` operator: `<condition1> [AND <condition2> [<...> AND <conditionN>]]`.

    Each condition has the form `<field> <operator> <value>`, where:
    1. `<field>` is the field name. Currently you can use filtering only on the limited number of fields.
    2. `<operator>` is a logical operator, one of `=`, `!=`, `IN`, `NOT IN`.
    3. `<value>` represents a value.
    String values should be written in double (`"`) or single (`'`) quotes. C-style escape sequences are supported (`\\"` turns to `"`, `\\'` to `'`, `\\\\` to backslash).
    Currently you can use filtering only on the [Host.id] field.
    To get the host ID, use [HostGroupService.ListHosts] request.
    """
    def __init__(
        self,
        *,
        host_group_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "host_group_id", b"host_group_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListHostGroupInstancesRequest = ListHostGroupInstancesRequest

@typing.final
class ListHostGroupInstancesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INSTANCES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is more than [ListHostGroupInstancesRequest.page_size], use
    [next_page_token] as the value
    for the [ListHostGroupInstancesRequest.page_token] query parameter
    in the next list request. Each subsequent list request will have its own
    [next_page_token] to continue paging through the results.
    """
    @property
    def instances(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.compute.v1.instance_pb2.Instance]:
        """Lists instances for the specified host group."""

    def __init__(
        self,
        *,
        instances: collections.abc.Iterable[yandex.cloud.compute.v1.instance_pb2.Instance] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["instances", b"instances", "next_page_token", b"next_page_token"]) -> None: ...

global___ListHostGroupInstancesResponse = ListHostGroupInstancesResponse

@typing.final
class ListHostGroupHostsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_GROUP_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    host_group_id: builtins.str
    """ID of the host group to list hosts for.
    To get the host group ID, use [HostGroupService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListHostGroupHostsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token. To get the next page of results,
    set [page_token] to the [ListHostGroupHostsResponse.next_page_token]
    returned by a previous list request.
    """
    def __init__(
        self,
        *,
        host_group_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["host_group_id", b"host_group_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListHostGroupHostsRequest = ListHostGroupHostsRequest

@typing.final
class ListHostGroupHostsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOSTS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is more than [ListHostGroupHostsRequest.page_size], use
    [next_page_token] as the value
    for the [ListHostGroupHostsRequest.page_token] query parameter
    in the next list request. Each subsequent list request will have its own
    [next_page_token] to continue paging through the results.
    """
    @property
    def hosts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.compute.v1.host_group_pb2.Host]:
        """Lists hosts for the specified host group."""

    def __init__(
        self,
        *,
        hosts: collections.abc.Iterable[yandex.cloud.compute.v1.host_group_pb2.Host] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["hosts", b"hosts", "next_page_token", b"next_page_token"]) -> None: ...

global___ListHostGroupHostsResponse = ListHostGroupHostsResponse

@typing.final
class UpdateHostGroupHostRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_GROUP_ID_FIELD_NUMBER: builtins.int
    HOST_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    DEADLINE_AT_FIELD_NUMBER: builtins.int
    host_group_id: builtins.str
    """ID of the host group to update."""
    host_id: builtins.str
    """ID of the host to update."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which fields of the Host are going to be updated."""

    @property
    def deadline_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """The date and time when this host will be automatically freed of instances.
        Timestamp in [RFC3339](https://www.ietf.org/rfc/rfc3339.txt) text format.
        """

    def __init__(
        self,
        *,
        host_group_id: builtins.str = ...,
        host_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        deadline_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["deadline_at", b"deadline_at", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["deadline_at", b"deadline_at", "host_group_id", b"host_group_id", "host_id", b"host_id", "update_mask", b"update_mask"]) -> None: ...

global___UpdateHostGroupHostRequest = UpdateHostGroupHostRequest

@typing.final
class UpdateHostGroupHostMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_GROUP_ID_FIELD_NUMBER: builtins.int
    HOST_ID_FIELD_NUMBER: builtins.int
    host_group_id: builtins.str
    """ID of the host group that is being updated."""
    host_id: builtins.str
    """ID of the host that is being updated."""
    def __init__(
        self,
        *,
        host_group_id: builtins.str = ...,
        host_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["host_group_id", b"host_group_id", "host_id", b"host_id"]) -> None: ...

global___UpdateHostGroupHostMetadata = UpdateHostGroupHostMetadata

@typing.final
class ListHostGroupOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_GROUP_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    host_group_id: builtins.str
    """ID of the host group to list operations for.
    To get the host group ID, use [HostGroupService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size], the service returns a [ListHostGroupOperationsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the
    [ListHostGroupOperationsResponse.next_page_token] returned by a previous list request.
    """
    def __init__(
        self,
        *,
        host_group_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["host_group_id", b"host_group_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListHostGroupOperationsRequest = ListHostGroupOperationsRequest

@typing.final
class ListHostGroupOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListHostGroupOperationsRequest.page_size], use the [next_page_token] as the value
    for the [ListHostGroupOperationsRequest.page_token] query parameter in the next list request.
    Each subsequent list request will have its own [next_page_token] to continue paging through the results.
    """
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]:
        """List of operations for the specified host group."""

    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListHostGroupOperationsResponse = ListHostGroupOperationsResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing
import yandex.cloud.smartwebsecurity.v1.security_profile_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class WafProfile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing.final
    class CoreRuleSet(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        INBOUND_ANOMALY_SCORE_FIELD_NUMBER: builtins.int
        PARANOIA_LEVEL_FIELD_NUMBER: builtins.int
        RULE_SET_FIELD_NUMBER: builtins.int
        inbound_anomaly_score: builtins.int
        """Anomaly score.
        Enter an integer within the range of 2 and 10000.
        The higher this value, the more likely it is that the request that satisfies the rule is an attack.
        See [Rules](/docs/smartwebsecurity/concepts/waf#anomaly) for more details.
        """
        paranoia_level: builtins.int
        """Paranoia level.
        Enter an integer within the range of 1 and 4.
        Paranoia level classifies rules according to their aggression. The higher the paranoia level, the better your protection,
        but also the higher the probability of WAF false positives.
        See [Rules](/docs/smartwebsecurity/concepts/waf#paranoia) for more details.
        NOTE: this option has no effect on enabling or disabling rules.
        it is used only as recommendation for user to enable all rules with paranoia_level <= this value.
        """
        @property
        def rule_set(self) -> global___RuleSet:
            """Rule set."""

        def __init__(
            self,
            *,
            inbound_anomaly_score: builtins.int = ...,
            paranoia_level: builtins.int = ...,
            rule_set: global___RuleSet | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["rule_set", b"rule_set"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["inbound_anomaly_score", b"inbound_anomaly_score", "paranoia_level", b"paranoia_level", "rule_set", b"rule_set"]) -> None: ...

    @typing.final
    class AnalyzeRequestBody(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        class _Action:
            ValueType = typing.NewType("ValueType", builtins.int)
            V: typing_extensions.TypeAlias = ValueType

        class _ActionEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[WafProfile.AnalyzeRequestBody._Action.ValueType], builtins.type):
            DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
            ACTION_UNSPECIFIED: WafProfile.AnalyzeRequestBody._Action.ValueType  # 0
            IGNORE: WafProfile.AnalyzeRequestBody._Action.ValueType  # 1
            """Ignore request."""
            DENY: WafProfile.AnalyzeRequestBody._Action.ValueType  # 2
            """Deny request."""

        class Action(_Action, metaclass=_ActionEnumTypeWrapper):
            """Action to perform if maximum size of body exceeded."""

        ACTION_UNSPECIFIED: WafProfile.AnalyzeRequestBody.Action.ValueType  # 0
        IGNORE: WafProfile.AnalyzeRequestBody.Action.ValueType  # 1
        """Ignore request."""
        DENY: WafProfile.AnalyzeRequestBody.Action.ValueType  # 2
        """Deny request."""

        IS_ENABLED_FIELD_NUMBER: builtins.int
        SIZE_LIMIT_FIELD_NUMBER: builtins.int
        SIZE_LIMIT_ACTION_FIELD_NUMBER: builtins.int
        is_enabled: builtins.bool
        """Possible to turn analyzer on and turn if off."""
        size_limit: builtins.int
        """Maximum size of body to pass to analyzer. In kilobytes."""
        size_limit_action: global___WafProfile.AnalyzeRequestBody.Action.ValueType
        """Action to perform if maximum size of body exceeded."""
        def __init__(
            self,
            *,
            is_enabled: builtins.bool = ...,
            size_limit: builtins.int = ...,
            size_limit_action: global___WafProfile.AnalyzeRequestBody.Action.ValueType = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["is_enabled", b"is_enabled", "size_limit", b"size_limit", "size_limit_action", b"size_limit_action"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    CLOUD_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    RULES_FIELD_NUMBER: builtins.int
    EXCLUSION_RULES_FIELD_NUMBER: builtins.int
    CORE_RULE_SET_FIELD_NUMBER: builtins.int
    ANALYZE_REQUEST_BODY_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the WAF profile."""
    folder_id: builtins.str
    """ID of the folder that the WAF profile belongs to."""
    cloud_id: builtins.str
    """ID of the cloud that the WAF profile belongs to."""
    name: builtins.str
    """Name of the WAF profile. The name is unique within the folder. 1-50 characters long."""
    description: builtins.str
    """Optional description of the WAF profile."""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Labels as `` key:value `` pairs. Maximum of 64 per resource."""

    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp in [RFC3339](https://www.ietf.org/rfc/rfc3339.txt) text format."""

    @property
    def rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___WafProfileRule]:
        """Settings for each rule in rule set."""

    @property
    def exclusion_rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___WafProfileExclusionRule]:
        """List of exclusion rules. See [Rules](/docs/smartwebsecurity/concepts/waf#exclusion-rules)."""

    @property
    def core_rule_set(self) -> global___WafProfile.CoreRuleSet:
        """Core rule set settings. See [Basic rule set](/docs/smartwebsecurity/concepts/waf#rules-set) for details."""

    @property
    def analyze_request_body(self) -> global___WafProfile.AnalyzeRequestBody:
        """The parameter is deprecated. Parameters for request body analyzer."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        cloud_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        rules: collections.abc.Iterable[global___WafProfileRule] | None = ...,
        exclusion_rules: collections.abc.Iterable[global___WafProfileExclusionRule] | None = ...,
        core_rule_set: global___WafProfile.CoreRuleSet | None = ...,
        analyze_request_body: global___WafProfile.AnalyzeRequestBody | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["analyze_request_body", b"analyze_request_body", "core_rule_set", b"core_rule_set", "created_at", b"created_at", "rule_set", b"rule_set"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["analyze_request_body", b"analyze_request_body", "cloud_id", b"cloud_id", "core_rule_set", b"core_rule_set", "created_at", b"created_at", "description", b"description", "exclusion_rules", b"exclusion_rules", "folder_id", b"folder_id", "id", b"id", "labels", b"labels", "name", b"name", "rule_set", b"rule_set", "rules", b"rules"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["rule_set", b"rule_set"]) -> typing.Literal["core_rule_set"] | None: ...

global___WafProfile = WafProfile

@typing.final
class WafProfileRule(google.protobuf.message.Message):
    """WafProfileRule object. Determines settings for each rule_id in rule set."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RULE_ID_FIELD_NUMBER: builtins.int
    IS_ENABLED_FIELD_NUMBER: builtins.int
    IS_BLOCKING_FIELD_NUMBER: builtins.int
    rule_id: builtins.str
    """Rule ID."""
    is_enabled: builtins.bool
    """Determines is it rule enabled or not."""
    is_blocking: builtins.bool
    """Determines is it rule blocking or not."""
    def __init__(
        self,
        *,
        rule_id: builtins.str = ...,
        is_enabled: builtins.bool = ...,
        is_blocking: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["is_blocking", b"is_blocking", "is_enabled", b"is_enabled", "rule_id", b"rule_id"]) -> None: ...

global___WafProfileRule = WafProfileRule

@typing.final
class WafProfileExclusionRule(google.protobuf.message.Message):
    """A WafProfileExclusionRule object. See [Exclusion rules](/docs/smartwebsecurity/concepts/waf#exclusion-rules)."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class ExcludeRules(google.protobuf.message.Message):
        """Determines list of excluded rules."""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        EXCLUDE_ALL_FIELD_NUMBER: builtins.int
        RULE_IDS_FIELD_NUMBER: builtins.int
        exclude_all: builtins.bool
        """Set this option true to exclude all rules."""
        @property
        def rule_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
            """List of rules to exclude."""

        def __init__(
            self,
            *,
            exclude_all: builtins.bool = ...,
            rule_ids: collections.abc.Iterable[builtins.str] | None = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["exclude_all", b"exclude_all", "rule_ids", b"rule_ids"]) -> None: ...

    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    EXCLUDE_RULES_FIELD_NUMBER: builtins.int
    LOG_EXCLUDED_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of exclusion rule."""
    description: builtins.str
    """Optional description of the rule. 0-512 characters long."""
    log_excluded: builtins.bool
    """Records the fact that an exception rule is triggered."""
    @property
    def condition(self) -> yandex.cloud.smartwebsecurity.v1.security_profile_pb2.Condition:
        """The condition for matching traffic."""

    @property
    def exclude_rules(self) -> global___WafProfileExclusionRule.ExcludeRules:
        """Exclude rules."""

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        description: builtins.str = ...,
        condition: yandex.cloud.smartwebsecurity.v1.security_profile_pb2.Condition | None = ...,
        exclude_rules: global___WafProfileExclusionRule.ExcludeRules | None = ...,
        log_excluded: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["condition", b"condition", "exclude_rules", b"exclude_rules"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["condition", b"condition", "description", b"description", "exclude_rules", b"exclude_rules", "log_excluded", b"log_excluded", "name", b"name"]) -> None: ...

global___WafProfileExclusionRule = WafProfileExclusionRule

@typing.final
class RuleSet(google.protobuf.message.Message):
    """A RuleSet object. Determines name and version of rule set."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    name: builtins.str
    """Name of rule set."""
    version: builtins.str
    """Version of rule set."""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["name", b"name", "version", b"version"]) -> None: ...

global___RuleSet = RuleSet



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from yandex.cloud.mdb.greenplum.v1 import cluster_pb2 as yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__pb2
from yandex.cloud.mdb.greenplum.v1 import cluster_service_pb2 as yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__service__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2

GRPC_GENERATED_VERSION = '1.70.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in yandex/cloud/mdb/greenplum/v1/cluster_service_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class ClusterServiceStub(object):
    """A set of methods for managing Greenplum® clusters.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Get = channel.unary_unary(
                '/yandex.cloud.mdb.greenplum.v1.ClusterService/Get',
                request_serializer=yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__service__pb2.GetClusterRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__pb2.Cluster.FromString,
                _registered_method=True)
        self.List = channel.unary_unary(
                '/yandex.cloud.mdb.greenplum.v1.ClusterService/List',
                request_serializer=yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__service__pb2.ListClustersRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__service__pb2.ListClustersResponse.FromString,
                _registered_method=True)
        self.Create = channel.unary_unary(
                '/yandex.cloud.mdb.greenplum.v1.ClusterService/Create',
                request_serializer=yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__service__pb2.CreateClusterRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.Update = channel.unary_unary(
                '/yandex.cloud.mdb.greenplum.v1.ClusterService/Update',
                request_serializer=yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__service__pb2.UpdateClusterRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.Expand = channel.unary_unary(
                '/yandex.cloud.mdb.greenplum.v1.ClusterService/Expand',
                request_serializer=yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__service__pb2.ExpandRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.Delete = channel.unary_unary(
                '/yandex.cloud.mdb.greenplum.v1.ClusterService/Delete',
                request_serializer=yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__service__pb2.DeleteClusterRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.Start = channel.unary_unary(
                '/yandex.cloud.mdb.greenplum.v1.ClusterService/Start',
                request_serializer=yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__service__pb2.StartClusterRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.Stop = channel.unary_unary(
                '/yandex.cloud.mdb.greenplum.v1.ClusterService/Stop',
                request_serializer=yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__service__pb2.StopClusterRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.Move = channel.unary_unary(
                '/yandex.cloud.mdb.greenplum.v1.ClusterService/Move',
                request_serializer=yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__service__pb2.MoveClusterRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.ListOperations = channel.unary_unary(
                '/yandex.cloud.mdb.greenplum.v1.ClusterService/ListOperations',
                request_serializer=yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__service__pb2.ListClusterOperationsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__service__pb2.ListClusterOperationsResponse.FromString,
                _registered_method=True)
        self.ListMasterHosts = channel.unary_unary(
                '/yandex.cloud.mdb.greenplum.v1.ClusterService/ListMasterHosts',
                request_serializer=yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__service__pb2.ListClusterHostsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__service__pb2.ListClusterHostsResponse.FromString,
                _registered_method=True)
        self.ListSegmentHosts = channel.unary_unary(
                '/yandex.cloud.mdb.greenplum.v1.ClusterService/ListSegmentHosts',
                request_serializer=yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__service__pb2.ListClusterHostsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__service__pb2.ListClusterHostsResponse.FromString,
                _registered_method=True)
        self.ListLogs = channel.unary_unary(
                '/yandex.cloud.mdb.greenplum.v1.ClusterService/ListLogs',
                request_serializer=yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__service__pb2.ListClusterLogsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__service__pb2.ListClusterLogsResponse.FromString,
                _registered_method=True)
        self.StreamLogs = channel.unary_stream(
                '/yandex.cloud.mdb.greenplum.v1.ClusterService/StreamLogs',
                request_serializer=yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__service__pb2.StreamClusterLogsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__service__pb2.StreamLogRecord.FromString,
                _registered_method=True)
        self.ListBackups = channel.unary_unary(
                '/yandex.cloud.mdb.greenplum.v1.ClusterService/ListBackups',
                request_serializer=yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__service__pb2.ListClusterBackupsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__service__pb2.ListClusterBackupsResponse.FromString,
                _registered_method=True)
        self.Backup = channel.unary_unary(
                '/yandex.cloud.mdb.greenplum.v1.ClusterService/Backup',
                request_serializer=yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__service__pb2.BackupClusterRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)
        self.Restore = channel.unary_unary(
                '/yandex.cloud.mdb.greenplum.v1.ClusterService/Restore',
                request_serializer=yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__service__pb2.RestoreClusterRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                _registered_method=True)


class ClusterServiceServicer(object):
    """A set of methods for managing Greenplum® clusters.
    """

    def Get(self, request, context):
        """Returns the specified Greenplum® cluster.

        To get the list of all available Greenplum® clusters, make a [List] request.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Retrieves a list of Greenplum® clusters that belong to the specified folder.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Create(self, request, context):
        """Creates a Greenplum® cluster in the specified folder.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Updates the specified Greenplum® cluster.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Expand(self, request, context):
        """Expands the specified Greenplum® cluster.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Deletes the specified Greenplum® cluster.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Start(self, request, context):
        """Starts the specified Greenplum® cluster.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Stop(self, request, context):
        """Stops the specified Greenplum® cluster.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Move(self, request, context):
        """Moves the specified Greenplum® cluster to the specified folder.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListOperations(self, request, context):
        """Retrieves the list of Operation resources for the specified cluster.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListMasterHosts(self, request, context):
        """Retrieves a list of master hosts for the specified cluster.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListSegmentHosts(self, request, context):
        """Retrieves a list of segment hosts for the specified cluster.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListLogs(self, request, context):
        """Retrieves logs for the specified Greenplum® cluster.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StreamLogs(self, request, context):
        """Same as [ListLogs] but using server-side streaming. Also allows for `tail -f` semantics.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListBackups(self, request, context):
        """Retrieves a list of available backups for the specified Greenplum® cluster.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Backup(self, request, context):
        """Creates a backup for the specified Greenplum cluster.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Restore(self, request, context):
        """Creates a new Greenplum® cluster using the specified backup.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ClusterServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__service__pb2.GetClusterRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__pb2.Cluster.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__service__pb2.ListClustersRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__service__pb2.ListClustersResponse.SerializeToString,
            ),
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__service__pb2.CreateClusterRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__service__pb2.UpdateClusterRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Expand': grpc.unary_unary_rpc_method_handler(
                    servicer.Expand,
                    request_deserializer=yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__service__pb2.ExpandRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__service__pb2.DeleteClusterRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Start': grpc.unary_unary_rpc_method_handler(
                    servicer.Start,
                    request_deserializer=yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__service__pb2.StartClusterRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Stop': grpc.unary_unary_rpc_method_handler(
                    servicer.Stop,
                    request_deserializer=yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__service__pb2.StopClusterRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Move': grpc.unary_unary_rpc_method_handler(
                    servicer.Move,
                    request_deserializer=yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__service__pb2.MoveClusterRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'ListOperations': grpc.unary_unary_rpc_method_handler(
                    servicer.ListOperations,
                    request_deserializer=yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__service__pb2.ListClusterOperationsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__service__pb2.ListClusterOperationsResponse.SerializeToString,
            ),
            'ListMasterHosts': grpc.unary_unary_rpc_method_handler(
                    servicer.ListMasterHosts,
                    request_deserializer=yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__service__pb2.ListClusterHostsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__service__pb2.ListClusterHostsResponse.SerializeToString,
            ),
            'ListSegmentHosts': grpc.unary_unary_rpc_method_handler(
                    servicer.ListSegmentHosts,
                    request_deserializer=yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__service__pb2.ListClusterHostsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__service__pb2.ListClusterHostsResponse.SerializeToString,
            ),
            'ListLogs': grpc.unary_unary_rpc_method_handler(
                    servicer.ListLogs,
                    request_deserializer=yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__service__pb2.ListClusterLogsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__service__pb2.ListClusterLogsResponse.SerializeToString,
            ),
            'StreamLogs': grpc.unary_stream_rpc_method_handler(
                    servicer.StreamLogs,
                    request_deserializer=yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__service__pb2.StreamClusterLogsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__service__pb2.StreamLogRecord.SerializeToString,
            ),
            'ListBackups': grpc.unary_unary_rpc_method_handler(
                    servicer.ListBackups,
                    request_deserializer=yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__service__pb2.ListClusterBackupsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__service__pb2.ListClusterBackupsResponse.SerializeToString,
            ),
            'Backup': grpc.unary_unary_rpc_method_handler(
                    servicer.Backup,
                    request_deserializer=yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__service__pb2.BackupClusterRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Restore': grpc.unary_unary_rpc_method_handler(
                    servicer.Restore,
                    request_deserializer=yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__service__pb2.RestoreClusterRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.mdb.greenplum.v1.ClusterService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('yandex.cloud.mdb.greenplum.v1.ClusterService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class ClusterService(object):
    """A set of methods for managing Greenplum® clusters.
    """

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.mdb.greenplum.v1.ClusterService/Get',
            yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__service__pb2.GetClusterRequest.SerializeToString,
            yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__pb2.Cluster.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.mdb.greenplum.v1.ClusterService/List',
            yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__service__pb2.ListClustersRequest.SerializeToString,
            yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__service__pb2.ListClustersResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.mdb.greenplum.v1.ClusterService/Create',
            yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__service__pb2.CreateClusterRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.mdb.greenplum.v1.ClusterService/Update',
            yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__service__pb2.UpdateClusterRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Expand(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.mdb.greenplum.v1.ClusterService/Expand',
            yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__service__pb2.ExpandRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.mdb.greenplum.v1.ClusterService/Delete',
            yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__service__pb2.DeleteClusterRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Start(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.mdb.greenplum.v1.ClusterService/Start',
            yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__service__pb2.StartClusterRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Stop(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.mdb.greenplum.v1.ClusterService/Stop',
            yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__service__pb2.StopClusterRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Move(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.mdb.greenplum.v1.ClusterService/Move',
            yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__service__pb2.MoveClusterRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListOperations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.mdb.greenplum.v1.ClusterService/ListOperations',
            yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__service__pb2.ListClusterOperationsRequest.SerializeToString,
            yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__service__pb2.ListClusterOperationsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListMasterHosts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.mdb.greenplum.v1.ClusterService/ListMasterHosts',
            yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__service__pb2.ListClusterHostsRequest.SerializeToString,
            yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__service__pb2.ListClusterHostsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListSegmentHosts(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.mdb.greenplum.v1.ClusterService/ListSegmentHosts',
            yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__service__pb2.ListClusterHostsRequest.SerializeToString,
            yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__service__pb2.ListClusterHostsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListLogs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.mdb.greenplum.v1.ClusterService/ListLogs',
            yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__service__pb2.ListClusterLogsRequest.SerializeToString,
            yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__service__pb2.ListClusterLogsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def StreamLogs(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/yandex.cloud.mdb.greenplum.v1.ClusterService/StreamLogs',
            yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__service__pb2.StreamClusterLogsRequest.SerializeToString,
            yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__service__pb2.StreamLogRecord.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListBackups(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.mdb.greenplum.v1.ClusterService/ListBackups',
            yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__service__pb2.ListClusterBackupsRequest.SerializeToString,
            yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__service__pb2.ListClusterBackupsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Backup(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.mdb.greenplum.v1.ClusterService/Backup',
            yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__service__pb2.BackupClusterRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Restore(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/yandex.cloud.mdb.greenplum.v1.ClusterService/Restore',
            yandex_dot_cloud_dot_mdb_dot_greenplum_dot_v1_dot_cluster__service__pb2.RestoreClusterRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: yandex/cloud/ai/vision/v2/image.proto
# Protobuf Python Version: 5.29.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    0,
    '',
    'yandex/cloud/ai/vision/v2/image.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%yandex/cloud/ai/vision/v2/image.proto\x12\x19yandex.cloud.ai.vision.v2\"\xa5\x01\n\x05Image\x12\x11\n\x07\x63ontent\x18\x01 \x01(\x0cH\x00\x12>\n\nimage_type\x18\x02 \x01(\x0e\x32*.yandex.cloud.ai.vision.v2.Image.ImageType\":\n\tImageType\x12\x1a\n\x16IMAGE_TYPE_UNSPECIFIED\x10\x00\x12\x08\n\x04JPEG\x10\x01\x12\x07\n\x03PNG\x10\x02\x42\r\n\x0bImageSourceBe\n\x1dyandex.cloud.api.ai.vision.v2ZDgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/vision/v2;visionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ai.vision.v2.image_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\035yandex.cloud.api.ai.vision.v2ZDgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/vision/v2;vision'
  _globals['_IMAGE']._serialized_start=69
  _globals['_IMAGE']._serialized_end=234
  _globals['_IMAGE_IMAGETYPE']._serialized_start=161
  _globals['_IMAGE_IMAGETYPE']._serialized_end=219
# @@protoc_insertion_point(module_scope)
